package im.zhaojun.system.mapper;

import im.zhaojun.system.model.DeptTree;
import im.zhaojun.system.model.VideoeRecordType;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface DeptTreeMapper {

    int deleteByPrimaryKey(String deptId);

    int insert(DeptTree dept);

    DeptTree selectByPrimaryKey(String deptId);

    int updateByPrimaryKey(DeptTree dept);

    List<DeptTree> selectByParentId(@Param("parentId") String parentId);

    List<DeptTree> selectAllTree(@Param("parent_id")String parent_id);
    List<DeptTree> selectAllVideoTree(@Param("parent_id")String parent_id);

    List<String> selectChildrenIDByPrimaryKey(@Param("deptId") String deptId);

    int selectMaxOrderNum();

    int swapSort(@Param("currentId") Integer currentId, @Param("swapId") Integer swapId);

    String[] listeventByvideoid(@Param("userId") String userId);

    List<VideoeRecordType> selectVideoeRecordType(@Param("videoId")String videoId);

    int delvideorecord(@Param("id")String id);


}